@@ -63,6 +63,7 @@ test_that("dimensions are correct", {
   expect_length(foo$b, 1L)
   expect_length(foo$direct, 1L)
   expect_length(foo$total, 1L)
+  expect_length(foo$ab, 1L)
   # individual regressions
   expect_length(coef(foo$fit_mx), 4L)
   expect_length(coef(foo$fit_ymx), 5L)
@@ -77,14 +78,15 @@ test_that("values of coefficients are correct", {
   expect_equivalent(foo$b, coef(foo$fit_ymx)["M"])
   expect_equivalent(foo$direct, coef(foo$fit_ymx)["X"])
   expect_equivalent(foo$total, foo$a * foo$b + foo$direct)
+  expect_equivalent(foo$ab, foo$a * foo$b)
 
 })
 
 test_that("output of coef() method has correct attributes", {
 
   coefficients <- coef(foo)
-  expect_length(coefficients, 4L)
-  expect_named(coefficients, c("a", "b", "Direct", "Total"))
+  expect_length(coefficients, 5L)
+  expect_named(coefficients, c("a", "b", "Direct", "Total", "ab"))
 
 })
 
@@ -94,6 +96,7 @@ test_that("coef() method returns correct values of coefficients", {
   expect_equivalent(coef(foo, parm = "b"), foo$b)
   expect_equivalent(coef(foo, parm = "Direct"), foo$direct)
   expect_equivalent(coef(foo, parm = "Total"), foo$total)
+  expect_equivalent(coef(foo, parm = "ab"), foo$ab)
 
 })
 
@@ -101,10 +104,11 @@ test_that("summary returns original object", {
   expect_identical(foo, bar)
 })
 
-test_that("object returned by setup_ellipse_plot() has correct structure", {
+test_that("object returned by setup_xxx_plot() has correct structure", {
 
   # not meaningful for median regression
   expect_error(setup_ellipse_plot(foo))
+  expect_error(setup_weight_plot(foo))
 
 })
 
